<?php
namespace Ep\Gath\DataStore;

use Ep\Gath\Plugin\Products;
use WC_Product_Variable_Data_Store_CPT;

/**
 * Class VariableDataStore
 *
 * @package Ep\Gath\DataStore
 * @author Elektronika Perhoč <web@ep.hr>
 * @link http://gitlab.ep.local/ep-framework/gath
 */
class VariableDataStore extends WC_Product_Variable_Data_Store_CPT
{
    /**
     * Read attributes from post meta.
     *
     * @param WC_Product $product Product object.
     */
    
    protected function read_attributes(&$product)
    {
        if ($product->get_id() < Products::ID_OFFSET) {
            return parent::read_attributes($product);
        }

        /** @var Products $gath */
        $gath = apply_filters('ep_gath_products', null);

        if (!$gath) {
            return parent::read_attributes($product);
        }

        $result = $gath->getRawResult($product->get_id());
        $attributes_key = array_key_exists('VarAttributes', $result) ? 'VarAttributes' : 'Attributes';

        if (isset($result[$attributes_key]) && is_array($result[$attributes_key]) && !empty($result[$attributes_key])) {
            /** @var \WC_Product_Attribute[] $attributes */
            $attributes = [];

            foreach ($result[$attributes_key] as $i => $attr) {
                $id = $attr['id'];

                if (!isset($attributes[$id])) {
                    $attribute = new \WC_Product_Attribute();
                    $attribute->set_id(0);
                    $attribute->set_name($attr['name']);
                    $attribute->set_options([$attr['value']]);
                    $attribute->set_position($i + 1);
                    $attribute->set_visible(1);
                    $attribute->set_variation($product->get_type() === 'variable' ? 1 : 0);
                    $attributes[$id] = $attribute;
                } else {
                    $options = $attributes[$id]->get_options();
                    $options[] = $attr['value'];
                    $attributes[$id]->set_options($options);
                }
            }
            $product->set_attributes(array_values($attributes));
        }
    }
}